@@ -1,30 +1,30 @@
 /******************************************************************************
  The computer software and associated documentation called STAMP hereinafter
  referred to as the WORK which is more particularly identified and described in 
- Appendix A of the file LICENSE.  Conditions and restrictions for use of
- this package are also in this file.
+ the LICENSE.  Conditions and restrictions for use of
+ this package are also in the LICENSE.
 
  The WORK is only available to licensed institutions.
 
  The WORK was developed by: 
 	Robert B. Russell and Geoffrey J. Barton
 
- Of current addresses:
+ Of current contact addresses:
 
  Robert B. Russell (RBR)             Geoffrey J. Barton (GJB)
- Biomolecular Modelling Laboratory   Laboratory of Molecular Biophysics
- Imperial Cancer Research Fund       The Rex Richards Building
- Lincoln's Inn Fields, P.O. Box 123  South Parks Road
- London, WC2A 3PX, U.K.              Oxford, OX1 3PG, U.K.
- Tel: +44 171 269 3583               Tel: +44 865 275368
- FAX: +44 171 269 3417               FAX: 44 865 510454
- e-mail: russell@icrf.icnet.uk       e-mail gjb@bioch.ox.ac.uk
- WWW: http://bonsai.lif.icnet.uk/    WWW: http://geoff.biop.ox.ac.uk/
+ Bioinformatics                      EMBL-European Bioinformatics Institute
+ SmithKline Beecham Pharmaceuticals  Wellcome Trust Genome Campus
+ New Frontiers Science Park (North)  Hinxton, Cambridge, CB10 1SD U.K.
+ Harlow, Essex, CM19 5AW, U.K.       
+ Tel: +44 1279 622 884               Tel: +44 1223 494 414
+ FAX: +44 1279 622 200               FAX: +44 1223 494 468
+ e-mail: russelr1@mh.uk.sbphrd.com   e-mail geoff@ebi.ac.uk
+                                     WWW: http://barton.ebi.ac.uk/
 
- The WORK is Copyright (1992,1993,1995,1996) University of Oxford
-	Administrative Offices
-	Wellington Square
-	Oxford OX1 2JD U.K.
+   The WORK is Copyright (1997,1998,1999) Robert B. Russell & Geoffrey J. Barton
+	
+	
+	
 
  All use of the WORK must cite: 
  R.B. Russell and G.J. Barton, "Multiple Protein Sequence Alignment From Tertiary
@@ -60,6 +60,9 @@ int getdomain(FILE *IN, struct domain_loc *domains, int *ndomain, int maxdomain,
 	(*gottrans)=0;
 	while(!end) {
 	  end=domdefine(&domains[count],&i,env,DSSP,IN,OUTPUT);
+/*	  printf("Domain %s\n",domains[count].id);
+          printdomain(stdout,domains[count],1); */
+
 	  if(i==1) (*gottrans)=1;
 	  if(end==-1) {
 	     fprintf(stderr,"error in domain specification file\n");
@@ -97,18 +100,21 @@ int domdefine(struct domain_loc *domain, int *gottrans, char *env, int DSSP, FIL
 	int nobjects;
 	int comment;
 	int pt;
+	int indom;
 
  	char c;
 	char *descriptor;
-	char *buff;
+	char *buff,*guff;
 	char *temp;
 	char *dirfile;
 	
 	FILE *TEST;
 
 	buff=(char*)malloc(2000*sizeof(char));
+	guff=(char*)malloc(2000*sizeof(char));
 	dirfile=(char*)malloc(500*sizeof(char));
 	descriptor=(char*)malloc(2000*sizeof(char));
+	(*gottrans)=0;
 	
 	if(DSSP) {
 	   sprintf(dirfile,"%s/dssp.directories",env);
@@ -119,34 +125,20 @@ int domdefine(struct domain_loc *domain, int *gottrans, char *env, int DSSP, FIL
 	/* Now then, the best way to do this is to skip the comments, and
 	 *  then just read in a buff starting after the last newline, and
 	 *  ending at the end brace */
-	
-	while((c=getc(INPUT))!=(char)EOF) {
-	   if(c!='%' && c!='#') { /* not a comment */
-	     /* lets just read in the whole thing */
-	     i=0;
-	     buff[i++]=c;
-	     while((c=getc(INPUT))!=(char)EOF && c!='}') {
-	       buff[i++]=c;
-	     }
-	     if(c==(char)EOF) break;
-	     buff[i]=c;
-	     buff[i+1]='\0';
-	     break;
-	   } else { /* skip over comment */
-	     while((c=getc(INPUT))!=(char)EOF && c!='\n');
-	     if(c==(char)EOF) break;
-	   }
-	}
-	if(c==(char)EOF) { /* End of file, no domain, exit */
-	   free(buff); free(dirfile); free(descriptor);
-	   return 1;
-	}
-	/* if we have a domain, and are not at the end of the file, 
-	 *  we should read until the end of the last line, to 
-	 *  leave the file pointer ready for next time */
-	while((c=getc(INPUT))!=(char)EOF && c!='\n');
 
-/*	printf("Domain is %s\n",buff);    */
+	indom = 0;
+	buff[0]='\0';
+	while(fgets(guff,1999,INPUT)!=NULL) {
+	     if((guff[0]!='%') && (guff[0]!='#')) {
+		if(strstr(guff,"{")!=NULL) { indom=1; }
+		if(indom) {
+			sprintf(&buff[strlen(buff)],"%s",guff);
+		}
+		if(strstr(guff,"}")!=NULL) { indom=0; break; }
+	     }
+	}
+		 
+/*	printf("Domain is %s\n",buff);      */
 
 	/* First read the file name */
 
@@ -154,7 +146,7 @@ int domdefine(struct domain_loc *domain, int *gottrans, char *env, int DSSP, FIL
 	pt=0;
 	if((pt=skiptononspace(buff,pt))==-1) getdomain_error(buff);
 	sscanf(&buff[pt],"%s",&domain[0].id[0]);	/* read the identifier */
-/*	printf("Read in file %s\n",domain[0].filename);  */
+/*	printf("Read in file %s\n",domain[0].filename); */
 
 	/* check to see whether the file exists, otherwise, look for a file
 	 *  with a similar ID */
@@ -165,6 +157,7 @@ int domdefine(struct domain_loc *domain, int *gottrans, char *env, int DSSP, FIL
 	    fprintf(OUTPUT,"file for %s not found, nor was any corrsponding file\n",domain[0].id);
 	    fprintf(OUTPUT,"   found in %s\n",dirfile);
 	    free(buff); free(dirfile); free(descriptor);
+	    free(guff);
 	    return -1; 
 	  } else {
 	    strcpy(&domain[0].filename[0],temp);
@@ -193,7 +186,7 @@ int domdefine(struct domain_loc *domain, int *gottrans, char *env, int DSSP, FIL
 	   j++;
 	}
 	descriptor[j]='\0';
-/*	printf("descriptor= '%s'\n",descriptor);    */
+/*	printf("descriptor= '%s'\n",descriptor);     */
 	/* allocation of memory, initially */
 	domain[0].reverse=(int*)malloc(sizeof(int));
 	domain[0].type=(int*)malloc(sizeof(int));
@@ -217,7 +210,7 @@ int domdefine(struct domain_loc *domain, int *gottrans, char *env, int DSSP, FIL
 	pt=0;
 	if(strlen(descriptor)==0) getdomain_error(buff);
 	while(descriptor[pt]==' ' && descriptor[pt]!='\0') pt++;
-	if(descriptor[pt]=='\0' || descriptor[pt]=='}') getdomain_error();
+	if(descriptor[pt]=='\0' || descriptor[pt]=='}') getdomain_error(buff);
 	while(pt!=-1 && descriptor[pt]!='\0' && descriptor[pt]!='\n') { /* read until end of string */
 	   if(strncmp(&descriptor[pt],"REVERSE",7)==0) { /* coordinates are to be reversed */
 		 domain[0].reverse[nobjects]=1;
@@ -301,25 +294,19 @@ int domdefine(struct domain_loc *domain, int *gottrans, char *env, int DSSP, FIL
 	   free(dirfile);
 	   free(descriptor);
 	   free(buff);
+	   free(guff);
 	   return 0;
 }
 
-int skiptononspace(string,pointer)
-char *string;
-int pointer;
-{
-/*	printf("Before skiptononspace '%s' %d\n",&string[pointer],pointer); */
+int skiptononspace(char *string, int pointer) {
 	while(string[pointer]!=' ' && string[pointer]!='\0' && string[pointer]!='\n') pointer++;
 	if(string[pointer]=='\0') return -1;
 	while(string[pointer]==' ' && string[pointer]!='\0' && string[pointer]!='\n') pointer++;
 	if(string[pointer]=='\0') return -1;
-/*	printf("After skiptononspace '%s' %d\n",&string[pointer],pointer); */
 	return pointer;
 }
 
-int getdomain_error(buff)
-char *buff;
-{
+void getdomain_error(char *buff) {
 	fprintf(stderr,"error in domain descriptors\n");
 	fprintf(stderr,"Last domain read:\n%s\n",buff);
 	exit(-1);
