@@ -1,30 +1,30 @@
 /******************************************************************************
  The computer software and associated documentation called STAMP hereinafter
  referred to as the WORK which is more particularly identified and described in 
- Appendix A of the file LICENSE.  Conditions and restrictions for use of
- this package are also in this file.
+ the LICENSE.  Conditions and restrictions for use of
+ this package are also in the LICENSE.
 
  The WORK is only available to licensed institutions.
 
  The WORK was developed by: 
 	Robert B. Russell and Geoffrey J. Barton
 
- Of current addresses:
+ Of current contact addresses:
 
  Robert B. Russell (RBR)             Geoffrey J. Barton (GJB)
- Biomolecular Modelling Laboratory   Laboratory of Molecular Biophysics
- Imperial Cancer Research Fund       The Rex Richards Building
- Lincoln's Inn Fields, P.O. Box 123  South Parks Road
- London, WC2A 3PX, U.K.              Oxford, OX1 3PG, U.K.
- Tel: +44 171 269 3583               Tel: +44 865 275368
- FAX: +44 171 269 3417               FAX: 44 865 510454
- e-mail: russell@icrf.icnet.uk       e-mail gjb@bioch.ox.ac.uk
- WWW: http://bonsai.lif.icnet.uk/    WWW: http://geoff.biop.ox.ac.uk/
+ Bioinformatics                      EMBL-European Bioinformatics Institute
+ SmithKline Beecham Pharmaceuticals  Wellcome Trust Genome Campus
+ New Frontiers Science Park (North)  Hinxton, Cambridge, CB10 1SD U.K.
+ Harlow, Essex, CM19 5AW, U.K.       
+ Tel: +44 1279 622 884               Tel: +44 1223 494 414
+ FAX: +44 1279 622 200               FAX: +44 1223 494 468
+ e-mail: russelr1@mh.uk.sbphrd.com   e-mail geoff@ebi.ac.uk
+                                     WWW: http://barton.ebi.ac.uk/
 
- The WORK is Copyright (1992,1993,1995,1996) University of Oxford
-	Administrative Offices
-	Wellington Square
-	Oxford OX1 2JD U.K.
+   The WORK is Copyright (1997,1998,1999) Robert B. Russell & Geoffrey J. Barton
+	
+	
+	
 
  All use of the WORK must cite: 
  R.B. Russell and G.J. Barton, "Multiple Protein Sequence Alignment From Tertiary
@@ -60,14 +60,17 @@ int getks(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 	   /* first check to see if there is a DSSP file that uses the whole ID name */
            filename=getfile(domain[i].id,parms[0].dsspfile,strlen(domain[i].id),parms[0].LOG);
 	   /* if there is, use it, otherwise try to get one using the four letter code */
-	   if(filename[0]=='\0') filename=getfile(domain[i].id,parms[0].dsspfile,4,parms[0].LOG);
+	   if(filename[0]=='\0') {
+		free(filename);
+		filename=getfile(domain[i].id,parms[0].dsspfile,4,parms[0].LOG);
+	   }
 	   if(filename[0]=='\0') {
 	      fprintf(parms[0].LOG," no DSSP file found for %s\n",domain[i].id);
 	      for(j=0; j<domain[i].ncoords; ++j) domain[i].sec[j]='?';
 	      domain[i].sec[j]='\0';
 	      retval=-1; /* if any of the sequences have missing secondary structures */
 	   } else {
-	      DSSP=fopen(filename,"r");
+	      DSSP=openfile(filename,"r");
 	      total=0;
 	      fprintf(parms[0].LOG," using file %s\n",filename);
 	      for(j=0; j<domain[i].nobj; ++j) {
@@ -76,9 +79,10 @@ int getks(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 		    (parms[0].MAX_SEQ_LEN-total),&add,parms[0].LOG)==-1) 
 		    retval=-1;
 	         total+=add;
-		 rewind(DSSP);
+		 closefile(DSSP,filename);
+	         DSSP=openfile(filename,"r");
 	      }
-	      fclose(DSSP);
+	      closefile(DSSP,filename);
 	      free(filename);
 	      if(total!=domain[i].ncoords) {
 		 fprintf(parms[0].LOG,"warning: DSSP summary found was incomplete -- the results may have errors\n");
