@@ -1,30 +1,30 @@
 /******************************************************************************
  The computer software and associated documentation called STAMP hereinafter
  referred to as the WORK which is more particularly identified and described in 
- Appendix A of the file LICENSE.  Conditions and restrictions for use of
- this package are also in this file.
+ the LICENSE.  Conditions and restrictions for use of
+ this package are also in the LICENSE.
 
  The WORK is only available to licensed institutions.
 
  The WORK was developed by: 
 	Robert B. Russell and Geoffrey J. Barton
 
- Of current addresses:
+ Of current contact addresses:
 
  Robert B. Russell (RBR)             Geoffrey J. Barton (GJB)
- Biomolecular Modelling Laboratory   Laboratory of Molecular Biophysics
- Imperial Cancer Research Fund       The Rex Richards Building
- Lincoln's Inn Fields, P.O. Box 123  South Parks Road
- London, WC2A 3PX, U.K.              Oxford, OX1 3PG, U.K.
- Tel: +44 171 269 3583               Tel: +44 865 275368
- FAX: +44 171 269 3417               FAX: 44 865 510454
- e-mail: russell@icrf.icnet.uk       e-mail gjb@bioch.ox.ac.uk
- WWW: http://bonsai.lif.icnet.uk/    WWW: http://geoff.biop.ox.ac.uk/
+ Bioinformatics                      EMBL-European Bioinformatics Institute
+ SmithKline Beecham Pharmaceuticals  Wellcome Trust Genome Campus
+ New Frontiers Science Park (North)  Hinxton, Cambridge, CB10 1SD U.K.
+ Harlow, Essex, CM19 5AW, U.K.       
+ Tel: +44 1279 622 884               Tel: +44 1223 494 414
+ FAX: +44 1279 622 200               FAX: +44 1223 494 468
+ e-mail: russelr1@mh.uk.sbphrd.com   e-mail geoff@ebi.ac.uk
+                                     WWW: http://barton.ebi.ac.uk/
 
- The WORK is Copyright (1992,1993,1995,1996) University of Oxford
-	Administrative Offices
-	Wellington Square
-	Oxford OX1 2JD U.K.
+   The WORK is Copyright (1997,1998,1999) Robert B. Russell & Geoffrey J. Barton
+	
+	
+	
 
  All use of the WORK must cite: 
  R.B. Russell and G.J. Barton, "Multiple Protein Sequence Alignment From Tertiary
@@ -36,8 +36,7 @@
 #include <math.h>
 #include <time.h>
 
-#include <general.h>
-#include <domain.h>
+#include <stamp.h>
 #include <stamprel.h>
 
 #define MAX_SEQ_LEN 2000
@@ -45,6 +44,9 @@
 
 /* gstamp: reads in a stamp output file and generates molscripts files
  *   displaying the regions of similarity */
+
+void exit_error();
+
 main(int argc, char *argv[]) {
 
 	int i,j,k,l,test;
@@ -59,6 +61,7 @@ main(int argc, char *argv[]) {
 	int gen_average;
 	int helix,strand,coil;
 	int cons_sec;
+	int colour;
 	int verbose;
 
 	int *counter;
@@ -100,7 +103,7 @@ main(int argc, char *argv[]) {
 	
 	buff=(char*)malloc(100*sizeof(char));
 	all_aligned=0; gen_average=0;
-	cons_sec=0; 
+	cons_sec=0; colour=0;
 
 	for(i=1; i<argc; ++i) {
 	   if(argv[i][0]!='-') exit_error();
@@ -130,6 +133,8 @@ main(int argc, char *argv[]) {
 	     gen_average=1;
 	   } else if(strcmp(&argv[i][1],"cons")==0) {
 	     cons_sec=1;
+	   } else if(strcmp(&argv[i][1],"colour")==0) {
+	     colour=1;
 	   } else if(strcmp(&argv[i][1],"V")==0) {
 	      verbose=1;
 	   } else {
@@ -174,7 +179,7 @@ main(int argc, char *argv[]) {
 	rewind(TRANS);
 	printf(" ");
 	if(Agetbloc(TRANS,bloc,&nbloc)==-1) {
-	  fprintf(stderr,"error: alignment file %s appears to be incomplete %s\n",filename); 
+	  fprintf(stderr,"error: alignment file %s appears to be incomplete\n",filename); 
 	  exit(-1); 
         } 
 	bloclen=strlen(&bloc[1].seq[1]);
@@ -242,7 +247,7 @@ main(int argc, char *argv[]) {
 	for(i=0; i<ndomain; ++i) {
 	   /* output the domain descriptors again */
 	   printf(" Domain %3d %s %s\n   ",i+1,domain[i].filename,domain[i].id); 
-	   if((PDB=fopen(domain[i].filename,"r"))==NULL) {
+	   if((PDB=openfile(domain[i].filename,"r"))==NULL) {
 	      fprintf(stderr,"error: file %s does not exist\n",domain[i].filename);
 	      exit(-1);
 	   }
@@ -269,7 +274,7 @@ main(int argc, char *argv[]) {
 		} 
 		printf("%4d CAs ",add); 
 	        total+=add;
-	        rewind(PDB);
+		closefile(PDB,domain[i].filename); PDB=openfile(domain[i].filename,"r");
 	    }
 	    domain[i].ncoords=total;
 	    printf(" A total of %4d CAs in total\n",domain[i].ncoords);
@@ -278,7 +283,7 @@ main(int argc, char *argv[]) {
 /*	    printmat(domain[i].R,domain[i].V,3,stdout);
 	    printf("      ...to these coordinates.\n");  */
 	    matmult(domain[i].R,domain[i].V,domain[i].coords,domain[i].ncoords,PRECISION);  
-	    fclose(PDB);
+	    closefile(PDB,domain[i].filename);
 	}
         summary=(char*)malloc(bloclen*sizeof(char));
 
@@ -336,9 +341,18 @@ main(int argc, char *argv[]) {
 	     type=summary[j];
 	     if(rel[j]==1) { /* reliable region */
                 switch(type) {
-                     case 'H':  fprintf(OUT,"helix "); break;
-                     case 'B':  fprintf(OUT,"strand "); break;
-                     default:   fprintf(OUT,"coil ");
+                     case 'H':  {
+				if(colour==1) fprintf(OUT,"set planecolour blue;\nset plane2colour blue;\n");
+				fprintf(OUT,"helix "); break;
+		     }
+                     case 'B':  {
+				if(colour==1) fprintf(OUT,"set planecolour red;\nset plane2colour red;\n");
+			 	fprintf(OUT,"strand "); break;
+		     }          
+                     default:   {
+			   if(colour==1) fprintf(OUT,"set planecolour white;\nset plane2colour white;\n");
+			   fprintf(OUT,"coil ");
+		     }
                 }
 	        fprintf(OUT,"from A%d to ",nres+1);
                 while(rel[j]==1 && j<bloclen && summary[j]==type) {
@@ -378,8 +392,8 @@ main(int argc, char *argv[]) {
 	    fprintf(OUT,"read mol \"%s.pdb\";\n",domain[i].id);
             fprintf(OUT,"  transform atom *\n");
             fprintf(OUT,"      by centre position atom *\n");
-            fprintf(OUT,"      by rotation x 90.0\n");
-            fprintf(OUT,"      by rotation y 170.0\n");
+            fprintf(OUT,"      by rotation x 0.0\n");
+            fprintf(OUT,"      by rotation y 0.0\n");
             fprintf(OUT,"      by rotation z 0.0\n");
             fprintf(OUT,"      ;\n");
             fprintf(OUT," set shading 0.0;\n");
@@ -394,10 +408,19 @@ main(int argc, char *argv[]) {
 	      if(type!=' ') {
 	        if(rel[j]==1) { /* reliable region */
 		  switch(type) {
-		     case 'H':  fprintf(OUT,"helix "); break;
-		     case 'B':  fprintf(OUT,"strand "); break;
-		     default:   fprintf(OUT,"coil ");
-		  }
+                     case 'H':  {
+                                if(colour==1) fprintf(OUT,"set planecolour blue;\nset plane2colour blue;\n");
+                                fprintf(OUT,"helix "); break;
+                     }
+                     case 'B':  {
+                                if(colour==1) fprintf(OUT,"set planecolour red;\nset plane2colour red;\n");
+                                fprintf(OUT,"strand "); break;
+                     }
+                     default:   {
+                           if(colour==1) fprintf(OUT,"set planecolour white;\nset plane2colour white;\n");
+                           fprintf(OUT,"coil ");
+                     }
+                  }
 		  if(type=='c' && nres>0 && rel[j-1]==1) { /* last residue can't be trace */
 	             fprintf(OUT,"from %c%d%c to ",
                         domain[i].numb[nres-1].cid,
@@ -470,7 +493,7 @@ main(int argc, char *argv[]) {
 
 	exit(0);
 }
-int exit_error()
+void exit_error()
 {
 	 fprintf(stderr,"format:  gstamp -f <file> -c <char> -w <win> -t <thresh> -a -aligned -cons\n");
  	 fprintf(stderr,"          -aligned ==> consider all aligned positions\n");
