@@ -1,30 +1,30 @@
 /******************************************************************************
  The computer software and associated documentation called STAMP hereinafter
  referred to as the WORK which is more particularly identified and described in 
- Appendix A of the file LICENSE.  Conditions and restrictions for use of
- this package are also in this file.
+ the LICENSE.  Conditions and restrictions for use of
+ this package are also in the LICENSE.
 
  The WORK is only available to licensed institutions.
 
  The WORK was developed by: 
 	Robert B. Russell and Geoffrey J. Barton
 
- Of current addresses:
+ Of current contact addresses:
 
  Robert B. Russell (RBR)             Geoffrey J. Barton (GJB)
- Biomolecular Modelling Laboratory   Laboratory of Molecular Biophysics
- Imperial Cancer Research Fund       The Rex Richards Building
- Lincoln's Inn Fields, P.O. Box 123  South Parks Road
- London, WC2A 3PX, U.K.              Oxford, OX1 3PG, U.K.
- Tel: +44 171 269 3583               Tel: +44 865 275368
- FAX: +44 171 269 3417               FAX: 44 865 510454
- e-mail: russell@icrf.icnet.uk       e-mail gjb@bioch.ox.ac.uk
- WWW: http://bonsai.lif.icnet.uk/    WWW: http://geoff.biop.ox.ac.uk/
+ Bioinformatics                      EMBL-European Bioinformatics Institute
+ SmithKline Beecham Pharmaceuticals  Wellcome Trust Genome Campus
+ New Frontiers Science Park (North)  Hinxton, Cambridge, CB10 1SD U.K.
+ Harlow, Essex, CM19 5AW, U.K.       
+ Tel: +44 1279 622 884               Tel: +44 1223 494 414
+ FAX: +44 1279 622 200               FAX: +44 1223 494 468
+ e-mail: russelr1@mh.uk.sbphrd.com   e-mail geoff@ebi.ac.uk
+                                     WWW: http://barton.ebi.ac.uk/
 
- The WORK is Copyright (1992,1993,1995,1996) University of Oxford
-	Administrative Offices
-	Wellington Square
-	Oxford OX1 2JD U.K.
+   The WORK is Copyright (1997,1998,1999) Robert B. Russell & Geoffrey J. Barton
+	
+	
+	
 
  All use of the WORK must cite: 
  R.B. Russell and G.J. Barton, "Multiple Protein Sequence Alignment From Tertiary
@@ -84,7 +84,7 @@ int makefile(struct domain_loc *domain, int ndomain, struct cluster cl,
 	fprintf(OUT,"Alignment length Lp = %d\n",length);
 	fprintf(OUT,"RMS deviation after fitting on %d atoms =  %f\n",nfit,rms);
 	fprintf(OUT,"Secondary structures are ");
-	switch(parms[0].SEC) {
+	switch(parms[0].SECTYPE) {
 	   case 0: fprintf(OUT,"not specified\n"); break;
 	   case 1: fprintf(OUT,"from DSSP\n"); break;
 	   case 2: fprintf(OUT,"read in from the file %s\n",parms[0].secfile);
@@ -101,7 +101,7 @@ int makefile(struct domain_loc *domain, int ndomain, struct cluster cl,
 	fprintf(OUT,">space \n");
 	for(i=0; i<cl.a.number; ++i) {
 	   fprintf(OUT,">%s_",domain[cl.a.member[i]].id);
-	   switch(parms[0].SEC) {
+	   switch(parms[0].SECTYPE) {
 	    case 0: fprintf(OUT,"none (cluster A) secondary structure not specified\n"); break;
             case 1: fprintf(OUT,"dssp (cluster A) secondary structure from DSSP\n"); break;
 	    case 2: fprintf(OUT,"spec read in from the file %s\n",parms[0].secfile);
@@ -111,7 +111,7 @@ int makefile(struct domain_loc *domain, int ndomain, struct cluster cl,
 
 	for(i=0; i<cl.b.number; ++i) {
 	   fprintf(OUT,">%s_",domain[cl.b.member[i]].id);
-	   switch(parms[0].SEC) {
+	   switch(parms[0].SECTYPE) {
 	      case 0: fprintf(OUT,"none  (cluster B) secondary structure not specified\n"); break;
 	      case 1: fprintf(OUT,"dssp  (cluster B) secondary structure from DSSP\n"); break;
 	      case 2: fprintf(OUT,"spec  (cluster B) secondary structure read in from the file %s\n",parms[0].secfile);
