@@ -1,30 +1,30 @@
 /******************************************************************************
  The computer software and associated documentation called STAMP hereinafter
  referred to as the WORK which is more particularly identified and described in 
- Appendix A of the file LICENSE.  Conditions and restrictions for use of
- this package are also in this file.
+ the LICENSE.  Conditions and restrictions for use of
+ this package are also in the LICENSE.
 
  The WORK is only available to licensed institutions.
 
  The WORK was developed by: 
 	Robert B. Russell and Geoffrey J. Barton
 
- Of current addresses:
+ Of current contact addresses:
 
  Robert B. Russell (RBR)             Geoffrey J. Barton (GJB)
- Biomolecular Modelling Laboratory   Laboratory of Molecular Biophysics
- Imperial Cancer Research Fund       The Rex Richards Building
- Lincoln's Inn Fields, P.O. Box 123  South Parks Road
- London, WC2A 3PX, U.K.              Oxford, OX1 3PG, U.K.
- Tel: +44 171 269 3583               Tel: +44 865 275368
- FAX: +44 171 269 3417               FAX: 44 865 510454
- e-mail: russell@icrf.icnet.uk       e-mail gjb@bioch.ox.ac.uk
- WWW: http://bonsai.lif.icnet.uk/    WWW: http://geoff.biop.ox.ac.uk/
+ Bioinformatics                      EMBL-European Bioinformatics Institute
+ SmithKline Beecham Pharmaceuticals  Wellcome Trust Genome Campus
+ New Frontiers Science Park (North)  Hinxton, Cambridge, CB10 1SD U.K.
+ Harlow, Essex, CM19 5AW, U.K.       
+ Tel: +44 1279 622 884               Tel: +44 1223 494 414
+ FAX: +44 1279 622 200               FAX: +44 1223 494 468
+ e-mail: russelr1@mh.uk.sbphrd.com   e-mail geoff@ebi.ac.uk
+                                     WWW: http://barton.ebi.ac.uk/
 
- The WORK is Copyright (1992,1993,1995,1996) University of Oxford
-	Administrative Offices
-	Wellington Square
-	Oxford OX1 2JD U.K.
+   The WORK is Copyright (1997,1998,1999) Robert B. Russell & Geoffrey J. Barton
+	
+	
+	
 
  All use of the WORK must cite: 
  R.B. Russell and G.J. Barton, "Multiple Protein Sequence Alignment From Tertiary
@@ -51,7 +51,6 @@ int pairfit(struct domain_loc *domain1, struct domain_loc *domain2, float *score
      int **prob;
      int not_gap,align_len;
      int seqcount,seccount;
-     int max_len;
      int n_sec_equiv,n_pos_equiv;
      int slen,neighbors;
      int nsec1,nsec2;
@@ -73,8 +72,10 @@ int pairfit(struct domain_loc *domain1, struct domain_loc *domain2, float *score
      struct cluster *cl;
      struct domain_loc *dcl;
 
-     v=(float*)malloc(3*sizeof(float*));
-     vt=(float*)malloc(3*sizeof(float*));
+/* SMJS Changed malloc(3*sizeof(float*) to malloc(3*sizeof(float) */
+     v=(float*)malloc(3*sizeof(float));
+/* SMJS Changed malloc(3*sizeof(float*) to malloc(3*sizeof(float) */
+     vt=(float*)malloc(3*sizeof(float));
      r=(float**)malloc(3*sizeof(float*));
      rt=(float**)malloc(3*sizeof(float*));
      for(i=0; i<3; ++i) {
@@ -117,7 +118,7 @@ int pairfit(struct domain_loc *domain1, struct domain_loc *domain2, float *score
 	   if(i==j) r[i][j]=rt[i][j]=1.0;
 	   else r[i][j]=rt[i][j]=0.0;
 	}
-     } /* End of for(i=0... */
+     } 
      rmsold=0.0;
      *score=0.0;
      scorediff=parms[0].SCORETOL+1;
@@ -226,8 +227,13 @@ int pairfit(struct domain_loc *domain1, struct domain_loc *domain2, float *score
         if(makefile(dcl,0,cl[0],count,(*score),(*rms),(*length),(*nfit),fpuse,fpuse,fpuse,fpuse,1,parms)==-1) return -1;
      }
      /* calculate pairwise sequence and secondary structure identity */
-     seqcount=seccount=align_len=c1=c2=0; n_sec_equiv=0; in_sec1=in_sec2=0;
+     seqcount=0; seccount=0;
+     align_len=0;
+     c1=0; c2=0; 
+     n_sec_equiv=0; 
+     in_sec1=0; in_sec2=0;
      n_pos_equiv=0;
+     (*nequiv) = 0;
      nsec1=nsec2=0; last_matched1=last_matched2=-1;
      slen=strlen(domain1[0].align);
      for(i=0; i<3; ++i) {
@@ -248,15 +254,22 @@ int pairfit(struct domain_loc *domain1, struct domain_loc *domain2, float *score
         }
 
 	neighbors=0;
-	for(j=i+1; j<slen && j<i+5; ++j) {
+	for(j=i+1; j<slen && j<(i+5); ++j) {
 	  if(fpuse[j]>=parms[0].second_CUTOFF) neighbors++;
 	  else break;
 	}
-	for(j=i-1; j>0 && j>i-5; --j) {
+	for(j=i-1; j>0 && j>(i-5); --j) {
 	   if(fpuse[j]>=parms[0].second_CUTOFF) neighbors++;
           else break;
         }
 	if(fpuse[i]>parms[0].second_CUTOFF && neighbors>=2) {
+
+	    /* identities are only in structural equivalences */
+	    if(not_gap && domain1[0].align[i]==domain2[0].align[i]) {
+			seqcount++; 
+	    } 
+	    if(not_gap && ss1==ss2) seccount++;
+
             n_pos_equiv++;
 	    if(ss1=='H') xpos=0;
 	    else if(ss1=='B') xpos=1;
@@ -268,7 +281,7 @@ int pairfit(struct domain_loc *domain1, struct domain_loc *domain2, float *score
             if(xpos!=ypos) hbcmat[ypos][xpos]++;
 	}
 
-/*	printf("%c %c %c %c %7.5f %4d ",domain1[0].align[i],domain2[0].align[i],ss1,ss2,fpuse[i],touse[i]);  */
+/*	printf("%c %c %c(%c) %c(%c) %7.5f %4d ",domain1[0].align[i],domain2[0].align[i],ss1,domain1[0].sec[c1],ss2,domain2[0].sec[c2],fpuse[i],touse[i]);*/
 	if(ss1=='c') {
           in_sec1=0;
  	}  else {
@@ -282,14 +295,12 @@ int pairfit(struct domain_loc *domain1, struct domain_loc *domain2, float *score
            in_sec2=1;
         }
 
+        /*printf("Conditions: not_gap = %d, in_sec1 = %d, in_sec2 = %d fpuse[%d]>=parms[0].second_CUTOFF = %d, neighbors>=2 = %d, (nsec1!=last_matched1 || nsec2!=last_matched2) = %d\n",not_gap,in_sec1,in_sec2,i,fpuse[i]>=parms[0].second_CUTOFF,neighbors>=2,(nsec1!=last_matched1 || nsec2!=last_matched2)); */
 	if(not_gap && in_sec1 && in_sec2 && fpuse[i]>=parms[0].second_CUTOFF && neighbors>=2 && (nsec1!=last_matched1 || nsec2!=last_matched2)) {
 	    n_sec_equiv++;
 	    last_matched1=nsec1;
 	    last_matched2=nsec2;
 	}
-/*	printf("%d %d %d %d %d\n",in_sec1,in_sec2,nsec1,nsec2,n_sec_equiv);  */
-	if(not_gap && domain1[0].align[i]==domain2[0].align[i]) seqcount++;
-	if(not_gap && ss1==ss2) seccount++;
 	if(domain1[0].align[i]!=' ') c1++;
 	if(domain2[0].align[i]!=' ') c2++;
 	if(c1>0 && c1<=(strlen(domain1[0].sec)-1) && c2>0 && c2<=(strlen(domain2[0].sec)-1)) align_len++;
@@ -299,13 +310,12 @@ int pairfit(struct domain_loc *domain1, struct domain_loc *domain2, float *score
      fprintf(parms[0].LOG,"Alignment length: %4d, seqid: %4d, secid: %4d, n_sec_equiv: %4d\n",align_len,seqcount,seccount,n_sec_equiv);
      (*nsec)=n_sec_equiv;
      (*nequiv)=n_pos_equiv;
-     max_len=max(domain1[0].ncoords,domain2[0].ncoords);
-     if(i==0 || (*score)<0.01) {
+     if((i==0) || ((*score)<0.01) || ((*nequiv)<=0)) {
 	(*seqid)=0.0;
 	(*secid)=0.0;
      } else {
-        (*seqid)=100.0*(float)seqcount/(float)max_len;
-        (*secid)=100.0*(float)seccount/(float)max_len;
+        (*seqid)=100.0*(float)seqcount/(float)(*nequiv);
+        (*secid)=100.0*(float)seccount/(float)(*nequiv);
      }
      /* this means that the coordinates, at the moment are the original coordinates transformed by domain2[0].r/v */
 
