@@ -1,30 +1,30 @@
 /******************************************************************************
  The computer software and associated documentation called STAMP hereinafter
  referred to as the WORK which is more particularly identified and described in 
- Appendix A of the file LICENSE.  Conditions and restrictions for use of
- this package are also in this file.
+ the LICENSE.  Conditions and restrictions for use of
+ this package are also in the LICENSE.
 
  The WORK is only available to licensed institutions.
 
  The WORK was developed by: 
 	Robert B. Russell and Geoffrey J. Barton
 
- Of current addresses:
+ Of current contact addresses:
 
  Robert B. Russell (RBR)             Geoffrey J. Barton (GJB)
- Biomolecular Modelling Laboratory   Laboratory of Molecular Biophysics
- Imperial Cancer Research Fund       The Rex Richards Building
- Lincoln's Inn Fields, P.O. Box 123  South Parks Road
- London, WC2A 3PX, U.K.              Oxford, OX1 3PG, U.K.
- Tel: +44 171 269 3583               Tel: +44 865 275368
- FAX: +44 171 269 3417               FAX: 44 865 510454
- e-mail: russell@icrf.icnet.uk       e-mail gjb@bioch.ox.ac.uk
- WWW: http://bonsai.lif.icnet.uk/    WWW: http://geoff.biop.ox.ac.uk/
+ Bioinformatics                      EMBL-European Bioinformatics Institute
+ SmithKline Beecham Pharmaceuticals  Wellcome Trust Genome Campus
+ New Frontiers Science Park (North)  Hinxton, Cambridge, CB10 1SD U.K.
+ Harlow, Essex, CM19 5AW, U.K.       
+ Tel: +44 1279 622 884               Tel: +44 1223 494 414
+ FAX: +44 1279 622 200               FAX: +44 1223 494 468
+ e-mail: russelr1@mh.uk.sbphrd.com   e-mail geoff@ebi.ac.uk
+                                     WWW: http://barton.ebi.ac.uk/
 
- The WORK is Copyright (1992,1993,1995,1996) University of Oxford
-	Administrative Offices
-	Wellington Square
-	Oxford OX1 2JD U.K.
+   The WORK is Copyright (1997,1998,1999) Robert B. Russell & Geoffrey J. Barton
+	
+	
+	
 
  All use of the WORK must cite: 
  R.B. Russell and G.J. Barton, "Multiple Protein Sequence Alignment From Tertiary
@@ -39,6 +39,7 @@
 int pairwise(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 
 	int i,j,k,l;
+	int n,m;
 	int length,nfit;
 	int start1,end1;
 	int start2,end2;
@@ -53,6 +54,8 @@ int pairwise(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 	float secdist,ratio;
 	float **pairmat;
 
+ 	double Pm;
+
 	FILE *MAT;
 
 	fprintf(parms[0].LOG,"\n\nPAIRWISE comparisons\n");
@@ -75,8 +78,11 @@ int pairwise(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 	    printf("\n    Sc = STAMP score, RMS = RMS deviation, Align = alignment length\n");
 	    printf("    Len1, Len2 = length of domain, Nfit = residues fitted\n");
 	    printf("    Secs = no. equivalent sec. strucs. Eq = no. equivalent residues\n");
-	    printf("     %%I = seq. identity, %%S = sec. str. identity\n\n");
-	    printf("     No.   Domain1  Domain2 Sc     RMS    Len1 Len2  Align NFit Eq. Secs.   %%I   %%S \n");
+	    printf("    %%I = seq. identity, %%S = sec. str. identity\n");
+	    printf("    P(m)  = P value (p=1/10) calculated after Murzin (1993), JMB, 230, 689-694\n\n");
+	    printf("     No.  Domain1         Domain2         Sc     RMS    Len1 Len2  Align NFit Eq. Secs.   %%I   %%S   P(m)\n");
+
+
 /* 	           "Pair   1      4mbn    2hhba 7.71 100.00    153   141        133   7  132"  */  
 
 	}
@@ -86,6 +92,7 @@ int pairwise(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 	      fprintf(parms[0].LOG,"\n\nComparison  %d, %s and %s\n",k+1,domain[i].id,domain[j].id);
 	      /* now perform either one or two comparisons as requested *
 	       * first fit */
+	      score=0.0;
 	      if(parms[0].NPASS==2) {
 		 if(parms[0].BOOLEAN) 
 	      	   fprintf(parms[0].LOG,"First fit: BOOLCUT = %5.3f\n",parms[0].first_BOOLCUT);
@@ -99,13 +106,16 @@ int pairwise(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 		parms[0].BOOLCUT=parms[0].first_BOOLCUT;		
 		if(pairfit(&domain[i],&domain[j],&score,&rms,&length,&nfit,parms,0,&start1,&end1,&start2,&end2,&seqid,&secid,&nequiv,&nsec,hbcmat,0,-1,0)==-1) return -1;
 		fprintf(parms[0].LOG,"Second fit: ");
-	      } else fprintf(parms[0].LOG,"Fitting with: ");
+	      } else {
+		fprintf(parms[0].LOG,"Fitting with: ");
+	      }
 	      if((score>=parms[0].first_THRESH) || parms[0].NPASS==1) {
-		 if(parms[0].BOOLEAN)
+		 if(parms[0].BOOLEAN) {
 	     	   fprintf(parms[0].LOG,"BOOLCUT = %5.3f\n",parms[0].second_BOOLCUT);
-		 else
+		 } else {
 		   fprintf(parms[0].LOG,"E1 = %5.2f, E2 = %5.2f, CUT=%5.2f, PEN = %5.2f\n",
 		      parms[0].second_E1,parms[0].second_E2,parms[0].second_CUTOFF,parms[0].second_PAIRPEN);
+		 }
 	         parms[0].const1=-2*parms[0].second_E1*parms[0].second_E1;
 	         parms[0].const2=-2*parms[0].second_E2*parms[0].second_E2;
 	         parms[0].PAIRPEN=parms[0].second_PAIRPEN;
@@ -116,9 +126,9 @@ int pairwise(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 		 fprintf(parms[0].LOG,"not performed since Sc < %7.3f\n",parms[0].first_THRESH);
 		 score/=10.0;
 	      }
-	      if(parms[0].SEC!=0) { /* secondary structure distance */
-		sec_content(domain[i].sec,domain[i].ncoords,parms[0].SEC,&a1,&b1,&c1);
-		sec_content(domain[j].sec,domain[j].ncoords,parms[0].SEC,&a2,&b2,&c2);
+	      if(parms[0].SECTYPE!=0) { /* secondary structure distance */
+		sec_content(domain[i].sec,domain[i].ncoords,parms[0].SECTYPE,&a1,&b1,&c1);
+		sec_content(domain[j].sec,domain[j].ncoords,parms[0].SECTYPE,&a2,&b2,&c2);
 		fprintf(parms[0].LOG,"secondary structure: %10s,  H: %3d, S: %3d (C: %3d)\n",
 			domain[i].id,a1,b1,c1);
 	        fprintf(parms[0].LOG,"secondary structure: %10s,  H: %3d, S: %3d (C: %3d)\n",
@@ -128,15 +138,24 @@ int pairwise(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 	      } else { 
 		secdist=0.0;
 	      }
+
+	      m = (int)(nequiv*seqid/(float)100);
+              n = nequiv;
+              Pm = murzin_P(n,m,0.1);
+
 	      if(strcmp(parms[0].logfile,"silent")!=0) {
-	        fprintf(parms[0].LOG,"Sum: %s & %s, Sc: %7.3f, RMS: %7.3f, Len: %d, maxlen: %d nfit: %d nsec: %d nequiv %d\n",
-		      domain[i].id,domain[j].id,score,rms,length,max(domain[i].ncoords,domain[j].ncoords),nfit,nsec,nequiv);
+	        fprintf(parms[0].LOG,"Sum: %s & %s, Sc: %7.3f, RMS: %7.3f, Len: %d, maxlen: %d nfit: %d nsec: %d nequiv %d P(m, p=1/10) = %7.2e\n",
+		      domain[i].id,domain[j].id,score,rms,length,max(domain[i].ncoords,domain[j].ncoords),nfit,nsec,nequiv,Pm);
 	      } else {
-	         printf("Pair %3d  %8s %8s %4.2f %6.2f ",
+
+	         printf("Pair %3d  %-15s %-15s %4.2f %6.2f ",
                       k+1,domain[i].id,domain[j].id,score,rms);
 		 printf("  %4d %4d  %4d %4d %3d %4d ",
                       domain[i].ncoords,domain[j].ncoords,length,nfit,nequiv,nsec);
 		 printf("%6.2f %6.2f ",seqid,secid);
+	   	 if(Pm<1e-4) { printf("%7.2e",Pm); }
+                 else { printf("%7.5f",Pm); }
+
 		 if(score<2.0) {
   		    printf(" LOW SCORE");
 		 }
@@ -154,10 +173,7 @@ int pairwise(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 	      /* create the similarity matrix */
 	      if(parms[0].CLUSTMETHOD==0) pairmat[i][j]=pairmat[j][i]=1/rms;
 	      if(parms[0].CLUSTMETHOD==1) pairmat[i][j]=pairmat[j][i]=(float)score;
-	      l=clock();
-	      parms[0].CPUtime+=(float)l/(60000000);
-/*	      fprintf(parms[0].LOG,"after fitting:\n"); disp(domain[j],parms[0].LOG);  */
-	    } /* end of for (j=.... */ 
+	    } 
 	
 	fprintf(parms[0].LOG,"\nPairwise calculations done.\n\n");
 	/* Now we write pairmat to the file parms[0].matfile. */
@@ -173,8 +189,10 @@ int pairwise(struct domain_loc *domain, int ndomain, struct parameters *parms) {
 		}
 	fclose(MAT);
 
-	for(i=0; i<ndomain; ++i) free(pairmat[i]);
+	for(i=0; i<ndomain; ++i) { free(pairmat[i]); } 
 	free(pairmat);
+	for(i=0; i<3; ++i) { free(hbcmat[i]); }
+	free(hbcmat);
 
 	return 0;
-} /* end of pairwise */
+} 
