@@ -1,30 +1,30 @@
 /******************************************************************************
  The computer software and associated documentation called STAMP hereinafter
  referred to as the WORK which is more particularly identified and described in 
- Appendix A of the file LICENSE.  Conditions and restrictions for use of
- this package are also in this file.
+ the LICENSE.  Conditions and restrictions for use of
+ this package are also in the LICENSE.
 
  The WORK is only available to licensed institutions.
 
  The WORK was developed by: 
 	Robert B. Russell and Geoffrey J. Barton
 
- Of current addresses:
+ Of current contact addresses:
 
  Robert B. Russell (RBR)             Geoffrey J. Barton (GJB)
- Biomolecular Modelling Laboratory   Laboratory of Molecular Biophysics
- Imperial Cancer Research Fund       The Rex Richards Building
- Lincoln's Inn Fields, P.O. Box 123  South Parks Road
- London, WC2A 3PX, U.K.              Oxford, OX1 3PG, U.K.
- Tel: +44 171 269 3583               Tel: +44 865 275368
- FAX: +44 171 269 3417               FAX: 44 865 510454
- e-mail: russell@icrf.icnet.uk       e-mail gjb@bioch.ox.ac.uk
- WWW: http://bonsai.lif.icnet.uk/    WWW: http://geoff.biop.ox.ac.uk/
+ Bioinformatics                      EMBL-European Bioinformatics Institute
+ SmithKline Beecham Pharmaceuticals  Wellcome Trust Genome Campus
+ New Frontiers Science Park (North)  Hinxton, Cambridge, CB10 1SD U.K.
+ Harlow, Essex, CM19 5AW, U.K.       
+ Tel: +44 1279 622 884               Tel: +44 1223 494 414
+ FAX: +44 1279 622 200               FAX: +44 1223 494 468
+ e-mail: russelr1@mh.uk.sbphrd.com   e-mail geoff@ebi.ac.uk
+                                     WWW: http://barton.ebi.ac.uk/
 
- The WORK is Copyright (1992,1993,1995,1996) University of Oxford
-	Administrative Offices
-	Wellington Square
-	Oxford OX1 2JD U.K.
+   The WORK is Copyright (1997,1998,1999) Robert B. Russell & Geoffrey J. Barton
+	
+	
+	
 
  All use of the WORK must cite: 
  R.B. Russell and G.J. Barton, "Multiple Protein Sequence Alignment From Tertiary
@@ -46,7 +46,10 @@
  * Modification 7 March 1996 Fixed naff tendancy to put an extra
  *  residue on the first line (call me anal-retentive call me what you will) 
  * Modification 15 January 1997 Now outputs a more useful summary on
- *  the command line rather than "Chain B taken from PDB file /disk3/pdb/pdb1gsf.ent" */
+ *  the command line rather than "Chain B taken from PDB file /disk3/pdb/pdb1gsf.ent" 
+ * Change: FASTA format by default */
+
+void exit_error();
 
 main(int argc, char *argv[]) {
 
@@ -72,7 +75,7 @@ main(int argc, char *argv[]) {
 	max_len = 5000;
 	title_limit = -1; /* All of the title will be printed out (MAX 1000 hardwired) */
 	strcpy(&format[0],"NBRF(PIR)");
-	ftype=0; sepfiles=0;
+	ftype=1; sepfiles=0;
 
 	if(argc<3) exit_error();
 	for(i=1; i<argc; ++i) {
@@ -151,7 +154,7 @@ main(int argc, char *argv[]) {
 	for(i=0; i<ndomain; ++i) {
 	   skip[i]=0;
 	   if(ftype==0 && verbose==1) printf("Domain %3d %s %s ",i+1,domain[i].filename,domain[i].id); 
-	   if((PDB=fopen(domain[i].filename,"r"))==NULL) {
+	   if((PDB=openfile(domain[i].filename,"r"))==NULL) {
 	      if(ftype==0 && verbose==1) printf("\nError: file %s does not exist\n",domain[i].filename);
 	      if(ftype==0 && verbose==1) printf("\nSkipping this domain...\n");
 	      skip[i]=1;
@@ -181,7 +184,8 @@ main(int argc, char *argv[]) {
 			sprintf(&domain[i].align[strlen(domain[i].align)],"%s ",&buff[10]);
 		 }
 	     }
-	     rewind(PDB);
+	     closefile(PDB,domain[i].filename);
+	     PDB=openfile(domain[i].filename,"r");
 	     if(title_limit!=-1) domain[i].align[title_limit]='\0';
 	     for(j=0; j<strlen(domain[i].align); ++j) {
 		if(domain[i].align[j]=='\n') domain[i].align[j]=' ';
@@ -208,7 +212,9 @@ main(int argc, char *argv[]) {
 	       }
 	       if(ftype==0 && verbose==1) printf("%4d CAs ",add);
 	       total+=add;
-	       rewind(PDB);
+	       closefile(PDB,domain[i].filename);
+               PDB=openfile(domain[i].filename,"r");
+
 	     }
 	     domain[i].ncoords=total;
 	     if(ftype==0 && verbose==1) printf("= %4d CAs in total\n",domain[i].ncoords);
@@ -216,7 +222,8 @@ main(int argc, char *argv[]) {
 		if(ftype==0 && verbose==1) printf("Sequence is too short or too long, will ignore\n");
 		skip[i]=1;
 	     }
-	     fclose(PDB);
+	     closefile(PDB,domain[i].filename);
+
 	     if(ftype==0 && verbose==1) { printf("Descriptor is %s\n",domain[i].align); }
 	   }
 	}
@@ -264,7 +271,7 @@ main(int argc, char *argv[]) {
 	}
 	exit(0);
 }
-int exit_error() {
+void exit_error() {
 
 	   fprintf(stderr,"format: pdbseq -f <domain descriptor file> [-min <val> -max <val>] > <output file>\n");
 	   fprintf(stderr,"               -format <pir, fasta> -separate -tl <title string max length>\n");
