@@ -1,30 +1,30 @@
 /******************************************************************************
  The computer software and associated documentation called STAMP hereinafter
  referred to as the WORK which is more particularly identified and described in 
- Appendix A of the file LICENSE.  Conditions and restrictions for use of
- this package are also in this file.
+ the LICENSE.  Conditions and restrictions for use of
+ this package are also in the LICENSE.
 
  The WORK is only available to licensed institutions.
 
  The WORK was developed by: 
 	Robert B. Russell and Geoffrey J. Barton
 
- Of current addresses:
+ Of current contact addresses:
 
  Robert B. Russell (RBR)             Geoffrey J. Barton (GJB)
- Biomolecular Modelling Laboratory   Laboratory of Molecular Biophysics
- Imperial Cancer Research Fund       The Rex Richards Building
- Lincoln's Inn Fields, P.O. Box 123  South Parks Road
- London, WC2A 3PX, U.K.              Oxford, OX1 3PG, U.K.
- Tel: +44 171 269 3583               Tel: +44 865 275368
- FAX: +44 171 269 3417               FAX: 44 865 510454
- e-mail: russell@icrf.icnet.uk       e-mail gjb@bioch.ox.ac.uk
- WWW: http://bonsai.lif.icnet.uk/    WWW: http://geoff.biop.ox.ac.uk/
+ Bioinformatics                      EMBL-European Bioinformatics Institute
+ SmithKline Beecham Pharmaceuticals  Wellcome Trust Genome Campus
+ New Frontiers Science Park (North)  Hinxton, Cambridge, CB10 1SD U.K.
+ Harlow, Essex, CM19 5AW, U.K.       
+ Tel: +44 1279 622 884               Tel: +44 1223 494 414
+ FAX: +44 1279 622 200               FAX: +44 1223 494 468
+ e-mail: russelr1@mh.uk.sbphrd.com   e-mail geoff@ebi.ac.uk
+                                     WWW: http://barton.ebi.ac.uk/
 
- The WORK is Copyright (1992,1993,1995,1996) University of Oxford
-	Administrative Offices
-	Wellington Square
-	Oxford OX1 2JD U.K.
+   The WORK is Copyright (1997,1998,1999) Robert B. Russell & Geoffrey J. Barton
+	
+	
+	
 
  All use of the WORK must cite: 
  R.B. Russell and G.J. Barton, "Multiple Protein Sequence Alignment From Tertiary
@@ -40,6 +40,8 @@
  *  expressed as a transformation of all domains onto the specified
  *  ID */
 
+void exit_error();
+
 main(int argc, char *argv[]) {
 	
 	
@@ -74,9 +76,12 @@ main(int argc, char *argv[]) {
 	buff=(char*)malloc(1000*sizeof(char));
 	infile=(char*)malloc(1000*sizeof(char));
 	indx=(int*)malloc(100*sizeof(int));
-	invmat=(float**)malloc(3*sizeof(float));
-	R=(float**)malloc(4*sizeof(float));
-	RI=(float**)malloc(4*sizeof(float));
+/* SMJS Was sizeof(float) */
+	invmat=(float**)malloc(3*sizeof(float *));
+/* SMJS Was sizeof(float) */
+	R=(float**)malloc(4*sizeof(float *));
+/* SMJS Was sizeof(float) */
+	RI=(float**)malloc(4*sizeof(float *));
 	negvec=(float*)malloc(3*sizeof(float));
 	for(i=0; i<4; ++i) { 
 	   R[i]=(float*)malloc(4*sizeof(float));
@@ -164,7 +169,7 @@ main(int argc, char *argv[]) {
 /*	printf("The matrix:\n");
 	printmat(domain[which].R,domain[which].V,3,stdout);
 */
-	matinv(R,RI,sign,indx);
+	matinv(R,RI,&sign,indx);
 
 	for(i=0; i<3; ++i) { 
 	   for(j=0; j<3; ++j) {
@@ -230,7 +235,7 @@ main(int argc, char *argv[]) {
 	exit(0);
 }
 
-int exit_error()
+void exit_error()
 {
 	fprintf(stderr,"format: pickframe -f <transformation file> -i <id to centre on> \n");
 	exit(-1);
