@@ -1,30 +1,30 @@
 /******************************************************************************
  The computer software and associated documentation called STAMP hereinafter
  referred to as the WORK which is more particularly identified and described in 
- Appendix A of the file LICENSE.  Conditions and restrictions for use of
- this package are also in this file.
+ the LICENSE.  Conditions and restrictions for use of
+ this package are also in the LICENSE.
 
  The WORK is only available to licensed institutions.
 
  The WORK was developed by: 
 	Robert B. Russell and Geoffrey J. Barton
 
- Of current addresses:
+ Of current contact addresses:
 
  Robert B. Russell (RBR)             Geoffrey J. Barton (GJB)
- Biomolecular Modelling Laboratory   Laboratory of Molecular Biophysics
- Imperial Cancer Research Fund       The Rex Richards Building
- Lincoln's Inn Fields, P.O. Box 123  South Parks Road
- London, WC2A 3PX, U.K.              Oxford, OX1 3PG, U.K.
- Tel: +44 171 269 3583               Tel: +44 865 275368
- FAX: +44 171 269 3417               FAX: 44 865 510454
- e-mail: russell@icrf.icnet.uk       e-mail gjb@bioch.ox.ac.uk
- WWW: http://bonsai.lif.icnet.uk/    WWW: http://geoff.biop.ox.ac.uk/
+ Bioinformatics                      EMBL-European Bioinformatics Institute
+ SmithKline Beecham Pharmaceuticals  Wellcome Trust Genome Campus
+ New Frontiers Science Park (North)  Hinxton, Cambridge, CB10 1SD U.K.
+ Harlow, Essex, CM19 5AW, U.K.       
+ Tel: +44 1279 622 884               Tel: +44 1223 494 414
+ FAX: +44 1279 622 200               FAX: +44 1223 494 468
+ e-mail: russelr1@mh.uk.sbphrd.com   e-mail geoff@ebi.ac.uk
+                                     WWW: http://barton.ebi.ac.uk/
 
- The WORK is Copyright (1992,1993,1995,1996) University of Oxford
-	Administrative Offices
-	Wellington Square
-	Oxford OX1 2JD U.K.
+   The WORK is Copyright (1997,1998,1999) Robert B. Russell & Geoffrey J. Barton
+	
+	
+	
 
  All use of the WORK must cite: 
  R.B. Russell and G.J. Barton, "Multiple Protein Sequence Alignment From Tertiary
@@ -65,6 +65,7 @@
 	-lF77 -lI77 -lm -lc   (in that order)
 */
 
+#include <stdio.h>
 #include <f2c.h>
 
 /* Table of constant values */
@@ -253,7 +254,8 @@ L200:
 
     for (i = 1; i <= 3; ++i) {
 	for (j = i; j <= 3; ++j) {
-	    t = (float)0.;
+/* SMJS Changed to be like Robs version */
+	    t = (doublereal)0.;
 	    for (k = 1; k <= 3; ++k) {
 		t += umat[k + i * 3] * umat[k + j * 3];
 /* L210: */
@@ -289,7 +291,8 @@ L200:
 
     for (i = 1; i <= 3; ++i) {
 	for (j = 1; j <= 3; ++j) {
-	    t = (float)0.;
+/* SMJS Changed to be like Robs version */
+	    t = (doublereal)0.;
 	    for (k = 1; k <= 3; ++k) {
 /* L230: */
 		t += umat[j + k * 3] * a[k + i * 3 - 4];
@@ -328,7 +331,8 @@ L200:
 
     for (i = 1; i <= 3; ++i) {
 	for (j = 1; j <= 3; ++j) {
-	    t = (float)0.;
+/* SMJS Changed to be like Robs version */
+	    t = (doublereal)0.;
 	    for (k = 1; k <= 3; ++k) {
 /* L260: */
 		t += b[i + k * 3 - 4] * a[j + k * 3 - 4];
@@ -672,31 +676,3 @@ L185:
     return 0;
 } /* esort_ */
 
-/******************************************************************************
- The computer software and associated documentation called STAMP hereinafter
- referred to as the WORK which is more particularly identified and described in 
- Appendix A of the file LICENSE.  Conditions and restrictions for use of
- this package are also in this file.
-
- The WORK was developed by: 
-	Robert B. Russell and Geoffrey J. Barton
-	Laboratory of Molecular Biophysics
-	University of Oxford
-	Rex Richards Building
-	South Parks Road
-	Oxford OX1 3QU U.K.
-	Tel:  (+44) 865-275379
-	FAX:  (+44) 865-510454
-	INTERNET: rbr@bioch.ox.ac.uk
-	JANET:    rbr@uk.ac.ox.bioch
-
- The WORK is Copyright (1993) University of Oxford
-	Administrative Offices
-	Wellington Square
-	Oxford OX1 2JD U.K.
-
- All use of the WORK must cite: 
- R.B. Russell and G.J. Barton, "Multiple Protein Sequence Alignment From Tertiary
-  Structure Comparison: Assignment of Global and Residue Confidence Levels",
-  PROTEINS: Structure, Function, and Genetics, 14:309--323 (1992).
-*****************************************************************************/
